@@ -1,4 +1,4 @@
-# last modified 2017-10-06 by J. Fox
+# last modified 2020-01-20 by J. Fox
 
 # File (and Edit) menu dialogs
 
@@ -23,7 +23,7 @@ loadLog <- function(){
 }
 
 saveLog <- function(logfilename) {
-  .logFileName <- if (missing(logfilename) || (logfilename == "%logfilename")) 
+  .logFileName <- if (missing(logfilename) || (logfilename == "%logfilename") || (logfilename == "logfilename")) 
     getRcmdr("logFileName") else logfilename
   if (is.null(.logFileName)) {
     saveLogAs()
@@ -294,7 +294,7 @@ closeCommander <- function(ask=TRUE, ask.save=ask){
 	open.showData.windows <- getRcmdr("open.showData.windows")
 	if (length(open.showData.windows) > 0){
 	  for (window in open.showData.windows){
-	    tkdestroy(window)
+	    if (window$ID %in% as.character(tkwinfo("children", "."))) tkdestroy(window)
 	  }
 	  putRcmdr("open.showData.windows", list())
 	}
@@ -651,9 +651,9 @@ Options <- function(){
   tkgrid(scientificNotationSliderFrame, sticky="w")
   tkgrid(labelRcmdr(outputTab, text=" "), sticky="w")    
   tkgrid(outputOptionsFrame, sticky="nw", columnspan = 3)
-  tkgrid(labelRcmdr(templateFrame, text="R Markdown template file"), rmdTemplateEntry, templateButton, sticky="w", padx=6)
+  tkgrid(labelRcmdr(templateFrame, text=gettextRcmdr("R Markdown template file")), rmdTemplateEntry, templateButton, sticky="w", padx=6)
   tkgrid(templateFrame, columnspan=2, sticky="w")
-  tkgrid(labelRcmdr(templateFrame, text="R knitr template file"), rnwTemplateEntry, rnwTemplateButton, sticky="w", padx=6)
+  tkgrid(labelRcmdr(templateFrame, text=gettextRcmdr("R knitr template file")), rnwTemplateEntry, rnwTemplateButton, sticky="w", padx=6)
   tkgrid(labelRcmdr(scaleFactorFrame, text=gettextRcmdr("Scale factor for Tk elements")), scaleFactorSlider, sticky="sw")
   tkgrid(scaleFactorFrame, sticky="w")
   tkgrid(labelRcmdr(otherTab, text=""))
@@ -902,7 +902,7 @@ saveOptions <- function(){
     tkgrid(optionsXscroll, sticky="ew", columnspan=2)
     tkgrid(optionsFrame, sticky="news", padx=10, pady=0)
     tkgrid(buttonsFrame, sticky="ew")
-    dialogSuffix()
+    dialogSuffix(bindReturn=FALSE)
 }
 
 loadPackages <- function(){
@@ -1052,11 +1052,11 @@ installSoftware <- function(){
         title=gettextRcmdr("Software to Install"))
     onOK <- function(){
         if (tclvalue(latexVariable) == "1"){
-            if (WindowsP()) browseURL("http://miktex.org/download")
-            else if (MacOSXP()) browseURL("http://www.tug.org/mactex/")
-            else browseURL("http://latex-project.org/ftp.html")
+            if (WindowsP()) browseURL("https://miktex.org/download")
+            else if (MacOSXP()) browseURL("https://www.tug.org/mactex/")
+            else browseURL("https://www.latex-project.org/get/")
         }
-        if (tclvalue(pandocVariable) == "1") browseURL("http://johnmacfarlane.net/pandoc/installing.html")
+        if (tclvalue(pandocVariable) == "1") browseURL("https://pandoc.org/installing.html")
         closeDialog()
         tkfocus(CommanderWindow())
     }
@@ -1066,3 +1066,38 @@ installSoftware <- function(){
     tkgrid(selectSoftwareFrame, sticky="w")
     dialogSuffix(grid.buttons=TRUE)
 }
+
+# the following function suggested by Vilmantas Gegzna
+
+# restartCommander <- function() {
+#   response <- tclvalue(RcmdrTkmessageBox(message=gettextRcmdr("Restart the Commander?"),
+#                                          icon="question", type="okcancel", default="cancel"))
+#   if (response == "cancel") return(invisible(response))
+#   else {
+#     response <- closeCommander(
+#       ask = getRcmdr("ask.to.exit"),
+#       ask.save = getRcmdr("ask.on.exit")
+#     )
+#     if (response == "cancel") return(invisible(response))
+#     else Commander()
+#   }
+# }
+
+restartCommander <- function(){
+  ask.save <- getRcmdr("ask.on.exit")
+  response <- tclvalue(RcmdrTkmessageBox(message=gettextRcmdr("Restart the Commander?"),
+                                         icon="question", type="okcancel", default="cancel"))
+  if (response == "cancel") return(invisible(response))
+  if (ask.save && getRcmdr("log.commands") && tclvalue(tkget(LogWindow(), "1.0", "end")) != "\n"){
+    response2 <- RcmdrTkmessageBox(message=gettextRcmdr("Save script file?"),
+                                   icon="question", type="yesno", default="yes")
+    if ("yes" == tclvalue(response2)) saveLog()
+  }
+  if (ask.save && getRcmdr("markdown.output") && getRcmdr("log.commands") && tclvalue(tkget(RmdWindow(), "1.0", "end")) != "\n"){
+    response2 <- RcmdrTkmessageBox(message=gettextRcmdr("Save R Markdown file?"),
+                                   icon="question", type="yesno", default="yes")
+    if ("yes" == tclvalue(response2)) saveRmd()
+  }
+  closeCommander(ask=FALSE)
+  Commander()
+}
